<span>
<pre>
    <a href="https://pypreservica.readthedocs.io/">
        <img src="https://github.com/carj/pyPreservica/blob/master/docs/images/logo1.JPG" align="left" />
    </a>
</pre>
</span>

# pyPreservica

Python language binding for the Preservica Entity API

https://preservica.com/

This library provides a Python class for working with the Entity API v6.1

https://us.preservica.com/api/entity/documentation.html

Wiki with example scripts https://github.com/carj/pyPreservica/wiki

## Documentation

The full documentation is available at: https://pypreservica.readthedocs.io/

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/carj/pyPreservica

## License

The package is available as open source under the terms of the Apache License 2.0
